@@ -62,7 +62,7 @@ class BaseDBClient:
             """Executing a query on the model."""
             _data = requests.get(request_path)
             if not _data.status_code == 200:
-                raise HTTPError(data['error_message'])
+                raise HTTPError(_data.json()['error_message'])
             return _data.json() if _data.status_code == 200 else None
 
         data = _get_object_by_id()
